@@ -9,12 +9,14 @@ import sop.exception.SOPGPException;
 import sop.external.ExternalSOP;
 import sop.operation.Dearmor;
 
-import java.io.IOException;
 import java.io.InputStream;
 import java.util.ArrayList;
 import java.util.List;
 import java.util.Properties;
 
+/**
+ * Implementation of the {@link Dearmor} operation using an external SOP binary.
+ */
 public class DearmorExternal implements Dearmor {
 
     private final List<String> commandList = new ArrayList<>();
@@ -27,7 +29,7 @@ public class DearmorExternal implements Dearmor {
     }
 
     @Override
-    public Ready data(InputStream data) throws SOPGPException.BadData, IOException {
-        return ExternalSOP.ready(Runtime.getRuntime(), commandList, envList, data);
+    public Ready data(InputStream data) throws SOPGPException.BadData {
+        return ExternalSOP.executeTransformingOperation(Runtime.getRuntime(), commandList, envList, data);
     }
 }
