@@ -19,8 +19,13 @@ public class SOPExecutionExceptionHandler implements CommandLine.IExecutionExcep
         // CHECKSTYLE:OFF
         if (ex.getMessage() != null) {
             commandLine.getErr().println(colorScheme.errorText(ex.getMessage()));
+        } else {
+            commandLine.getErr().println(ex.getClass().getName());
+        }
+
+        if (SopCLI.stacktrace) {
+            ex.printStackTrace(commandLine.getErr());
         }
-        ex.printStackTrace(commandLine.getErr());
         // CHECKSTYLE:ON
 
         return exitCode;
