@@ -8,6 +8,7 @@ import picocli.AutoComplete;
 import picocli.CommandLine;
 import sop.SOP;
 import sop.cli.picocli.commands.ArmorCmd;
+import sop.cli.picocli.commands.ChangeKeyPasswordCmd;
 import sop.cli.picocli.commands.DearmorCmd;
 import sop.cli.picocli.commands.DecryptCmd;
 import sop.cli.picocli.commands.InlineDetachCmd;
@@ -16,9 +17,12 @@ import sop.cli.picocli.commands.ExtractCertCmd;
 import sop.cli.picocli.commands.GenerateKeyCmd;
 import sop.cli.picocli.commands.InlineSignCmd;
 import sop.cli.picocli.commands.InlineVerifyCmd;
+import sop.cli.picocli.commands.ListProfilesCmd;
+import sop.cli.picocli.commands.RevokeKeyCmd;
 import sop.cli.picocli.commands.SignCmd;
 import sop.cli.picocli.commands.VerifyCmd;
 import sop.cli.picocli.commands.VersionCmd;
+import sop.exception.SOPGPException;
 
 import java.util.List;
 import java.util.Locale;
@@ -27,21 +31,29 @@ import java.util.ResourceBundle;
 @CommandLine.Command(
         name = "sop",
         resourceBundle = "msg_sop",
-        exitCodeOnInvalidInput = 69,
+        exitCodeOnInvalidInput = SOPGPException.UnsupportedSubcommand.EXIT_CODE,
         subcommands = {
-                CommandLine.HelpCommand.class,
-                ArmorCmd.class,
-                DearmorCmd.class,
-                DecryptCmd.class,
-                InlineDetachCmd.class,
-                EncryptCmd.class,
-                ExtractCertCmd.class,
+                // Meta Subcommands
+                VersionCmd.class,
+                ListProfilesCmd.class,
+                // Key and Certificate Management Subcommands
                 GenerateKeyCmd.class,
+                ChangeKeyPasswordCmd.class,
+                RevokeKeyCmd.class,
+                ExtractCertCmd.class,
+                // Messaging Subcommands
                 SignCmd.class,
                 VerifyCmd.class,
+                EncryptCmd.class,
+                DecryptCmd.class,
+                InlineDetachCmd.class,
                 InlineSignCmd.class,
                 InlineVerifyCmd.class,
-                VersionCmd.class,
+                // Transport Subcommands
+                ArmorCmd.class,
+                DearmorCmd.class,
+                // Miscellaneous Subcommands
+                CommandLine.HelpCommand.class,
                 AutoComplete.GenerateCompletion.class
         }
 )
