@@ -18,7 +18,7 @@ import java.util.List;
 
 @CommandLine.Command(name = "inline-sign",
         resourceBundle = "msg_inline-sign",
-        exitCodeOnInvalidInput = 37)
+        exitCodeOnInvalidInput = SOPGPException.UnsupportedOption.EXIT_CODE)
 public class InlineSignCmd extends AbstractSopCmd {
 
     @CommandLine.Option(names = "--no-armor",
@@ -41,6 +41,12 @@ public class InlineSignCmd extends AbstractSopCmd {
         InlineSign inlineSign = throwIfUnsupportedSubcommand(
                 SopCLI.getSop().inlineSign(), "inline-sign");
 
+        // Clearsigned messages are inherently armored, so --no-armor makes no sense.
+        if (!armor && type == InlineSignAs.clearsigned) {
+            String errorMsg = getMsg("sop.error.usage.incompatible_options.clearsigned_no_armor");
+            throw new SOPGPException.IncompatibleOptions(errorMsg);
+        }
+
         if (type != null) {
             try {
                 inlineSign.mode(type);
