@@ -4,8 +4,6 @@
 
 package sop.util;
 
-import sop.exception.SOPGPException;
-
 import java.nio.ByteBuffer;
 import java.nio.CharBuffer;
 import java.nio.charset.CharacterCodingException;
@@ -15,7 +13,8 @@ import java.nio.charset.CodingErrorAction;
 
 public class UTF8Util {
 
-    private static final CharsetDecoder UTF8Decoder = Charset.forName("UTF8")
+    public static final Charset UTF8 = Charset.forName("UTF8");
+    private static final CharsetDecoder UTF8Decoder = UTF8
             .newDecoder()
             .onUnmappableCharacter(CodingErrorAction.REPORT)
             .onMalformedInput(CodingErrorAction.REPORT);
@@ -27,14 +26,12 @@ public class UTF8Util {
      * @param data utf-8 encoded bytes
      *
      * @return decoded string
+     * @throws CharacterCodingException if the input data does not resemble UTF8
      */
-    public static String decodeUTF8(byte[] data) {
+    public static String decodeUTF8(byte[] data)
+            throws CharacterCodingException {
         ByteBuffer byteBuffer = ByteBuffer.wrap(data);
-        try {
-            CharBuffer charBuffer = UTF8Decoder.decode(byteBuffer);
-            return charBuffer.toString();
-        } catch (CharacterCodingException e) {
-            throw new SOPGPException.PasswordNotHumanReadable();
-        }
+        CharBuffer charBuffer = UTF8Decoder.decode(byteBuffer);
+        return charBuffer.toString();
     }
 }
